package tw.brad.book.mysensor;

import android.app.Activity;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.view.View;

public class AccelerometerTest extends Activity {
	private TestView tv;
	private SensorManager smgr;
	private Sensor sensor;
	private boolean isSensorEnable;
	private int rotation;
	private MySensorEventListener listener = null;
	private float x, y, z, sx, sy, sz;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		tv = new TestView(this);
		setContentView(tv);

		rotation = getWindowManager().getDefaultDisplay().getRotation();

		smgr = MainActivity.smgr;
		sensor = smgr.getDefaultSensor(Sensor.TYPE_ACCELEROMETER);
		// 偵測指定的感應器是否支援
		if (sensor != null) {
			isSensorEnable = true;
			listener = new MySensorEventListener();
		}

	}

	@Override
	protected void onResume() {
		super.onResume();
		if (isSensorEnable) {
			smgr.registerListener(listener, sensor,
					SensorManager.SENSOR_DELAY_UI);
		}
	}

	@Override
	protected void onPause() {
		super.onPause();
		if (listener != null) {
			smgr.unregisterListener(listener);
		}
	}

	private class MySensorEventListener implements SensorEventListener {
		// 精準度改變事件
		@Override
		public void onAccuracyChanged(Sensor sensor, int accuracy) {

		}

		// 感應事件
		@Override
		public void onSensorChanged(SensorEvent event) {
			x = event.values[0] * 7;
			y = event.values[1] * 7;
			z = event.values[2];

			if (rotation == 0) {
				sx = x;
				sy = y;
				sz = z;
			} else if (rotation == 3) {
				sx = y;
				sy = -1 * x;
				sz = z;
			}

			tv.addCX(-1 * sx);
			tv.addCY(sy);

			tv.postInvalidate();
		}

	}

	private class TestView extends View {
		private int viewW, viewH;
		private boolean isInited;
		private Paint paintText, paintValue;
		float cx, cy, cr;

		public TestView(Context context) {
			super(context);
			setBackgroundColor(Color.BLACK);

			paintText = new Paint();
			paintText.setTextSize(36);
			paintText.setColor(Color.YELLOW);

			paintValue = new Paint();
			paintValue.setTextSize(36);
			paintValue.setColor(Color.RED);
		}

		private void init() {
			viewW = getWidth();
			viewH = getHeight();

			cx = viewW / 2;
			cy = viewH / 2;
			cr = 50;

			isInited = true;
		}

		void addCX(float addX) {
			if (cx + cr + addX <= viewW && cx - cr + addX >= 0) {
				cx += addX;
			}
		}

		void addCY(float addY) {
			if (cy + cr + addY <= viewH && cy - cr + addY >= 0) {
				cy += addY;
			}
		}

		@Override
		protected void onDraw(Canvas canvas) {
			if (!isInited) {
				init();
				canvas.drawText(
						isSensorEnable ? "三軸加速器支援" + rotation : "裝置不支援",
						viewW / 4, viewH / 4, paintText);
			}
			canvas.drawCircle(cx, cy, cr, paintText);
		}
	}

}
