package tw.brad.book.mysensor;

import android.app.Activity;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.view.View;

public class PressureTest extends Activity {
	private TestView tv;
	private SensorManager smgr;
	private Sensor sensor;
	private boolean isSensorEnable;
	private int rotation;
	private MySensorEventListener listener = null;
	private float x, y, z, sx, sy, sz;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		tv = new TestView(this);
		setContentView(tv);

		rotation = getWindowManager().getDefaultDisplay().getRotation();

		smgr = MainActivity.smgr;
		sensor = smgr.getDefaultSensor(Sensor.TYPE_PRESSURE);
		// 偵測指定的感應器是否支援
		if (sensor != null) {
			isSensorEnable = true;
			listener = new MySensorEventListener();
		}
	}

	@Override
	protected void onResume() {
		super.onResume();
		if (isSensorEnable) {
			smgr.registerListener(listener, sensor,
					SensorManager.SENSOR_DELAY_UI);
			// SensorManager.SENSOR_DELAY_NORMAL: 200,000 microseconds
			// SensorManager.SENSOR_DELAY_UI: 60,000 microseconds
			// SensorManager.SENSOR_DELAY_GAME: 20,000 microseconds
			// SensorManager.SENSOR_DELAY_FASTEST: 0 microseconds
			// API Level 11+ 可以自行指定 n
		}
	}

	@Override
	protected void onPause() {
		super.onPause();
		if (listener != null) {
			smgr.unregisterListener(listener);
		}
	}

	private class MySensorEventListener implements SensorEventListener {
		private boolean isNotFirst;
		private float zFirst;

		// 精準度改變事件
		@Override
		public void onAccuracyChanged(Sensor sensor, int accuracy) {

		}

		// 感應事件
		@Override
		public void onSensorChanged(SensorEvent event) {
			x = event.values[0];
			y = event.values[1];
			z = event.values[2];

			if (rotation == 0){
				sx = x;
				sy = y;
				sz = z;
			}else if (rotation == 3){
				sx = -1*y;
				sy = -1*x;
				sz = z;
			}
			
			
			tv.cr = z * 10 + 30;

			tv.postInvalidate();
		}

	}

	private class TestView extends View {
		private int viewW, viewH;
		private boolean isInited;
		private Paint paintText, paintValue;
		float cx, cy, cr;

		public TestView(Context context) {
			super(context);
			setBackgroundColor(Color.BLACK);

			paintText = new Paint();
			paintText.setTextSize(36);
			paintText.setColor(Color.YELLOW);

			paintValue = new Paint();
			paintValue.setTextSize(36);
			paintValue.setColor(Color.RED);
		}

		private void init() {
			viewW = getWidth();
			viewH = getHeight();

			cx = viewW / 2;
			cy = viewH / 2;
			cr = 50;

			isInited = true;
		}

		@Override
		protected void onDraw(Canvas canvas) {
			if (!isInited) {
				init();
				canvas.drawText(isSensorEnable ? "大氣壓力感應器支援" : "裝置不支援",
						viewW / 8, viewH / 8, paintText);
			}

			canvas.drawText(sx + " : " + sy + " : " + sz, viewW / 8,viewH / 8, paintValue);
			canvas.drawCircle(cx, cy, Math.abs(cr), cr > 0 ? paintText
					: paintValue);
		}
	}

}
